podlist

package
v0.2.0-rc1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 17, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ChoosePodAndContainer

func ChoosePodAndContainer(ctx context.Context, clients k8s.KubernetesClients, reference kaiwo.KaiwoWorkload, predicates ...cliutils.PodSelectionPredicate) (string, string, error, bool)

ChoosePodAndContainer allows the User to choose the pod and the container they want to interact with predicates define an optional list of predicates that must be matched in order to include the pod in the list

Types

This section is empty.

Jump to