Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ResolvedRouting ¶
type ResolvedRouting struct {
Enabled bool
GatewayRef *gatewayapiv1.ParentReference
Annotations map[string]string
PathTemplate string
}
ResolvedRouting captures the effective routing configuration after applying service overrides on top of runtime defaults.
func Resolve ¶
func Resolve(service *aimv1alpha1.AIMService, runtime *aimv1alpha1.AIMRuntimeRoutingConfig) ResolvedRouting
Resolve determines the effective routing configuration by merging runtime config defaults with service-level overrides. The precedence order is: 1. Runtime config (base layer) 2. Service.Spec.Routing (override layer)
Click to show internal directories.
Click to hide internal directories.