Documentation
¶
Index ¶
- func AddExecFlags(cmd *cobra.Command)
- func AddMetaFlags(cmd *cobra.Command)
- func AddSchedulingFlags(cmd *cobra.Command)
- func ApplyConfigToFlags(cmd *cobra.Command, config *Config)
- func BuildServeCmd() *cobra.Command
- func BuildSubmitCmd() *cobra.Command
- func GetExecFlags() workloads.ExecFlags
- func GetMetaFlags() workloads.MetaFlags
- func GetSchedulingFlags() (*workloads.SchedulingFlags, error)
- func PreRunLoadConfig(cmd *cobra.Command, _ []string) error
- func RunApply(workload workloads.Workload, workloadMeta any) error
- type Config
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddExecFlags ¶
AddExecFlags adds flags that are needed for the execution of apply functions
func AddMetaFlags ¶
AddMetaFlags adds flags that are needed for basic Kubernetes metadata
func AddSchedulingFlags ¶
AddSchedulingFlags adds flags related to (Kueue) scheduling
func ApplyConfigToFlags ¶
func BuildServeCmd ¶
func BuildSubmitCmd ¶
func GetExecFlags ¶
func GetMetaFlags ¶
func GetSchedulingFlags ¶
func GetSchedulingFlags() (*workloads.SchedulingFlags, error)
GetSchedulingFlags initializes the scheduling flags with the number of GPUs requested
Types ¶
type Config ¶
type Config struct {
DryRun bool `yaml:"dryRun"`
CreateNamespace bool `yaml:"createNamespace"`
Path string `yaml:"path"`
OverlayPath string `yaml:"overlayPath"`
GpuNodeLabelKey string `yaml:"gpuNodeLabelKey"`
Template string `yaml:"template"`
Name string `yaml:"name"`
Namespace string `yaml:"namespace"`
Image string `yaml:"image"`
ImagePullSecret string `yaml:"imagePullSecret"`
Version string `yaml:"version"`
Gpus int `yaml:"gpus"`
RequestedReplicas int `yaml:"requestedReplicas"`
RequestedGPUsPerReplica int `yaml:"requestedGPUsPerReplica"`
}
func LoadConfigFromPath ¶
Click to show internal directories.
Click to hide internal directories.