Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ChoosePodAndContainer ¶
func ChoosePodAndContainer(ctx context.Context, clients k8s.KubernetesClients, reference kaiwo.KaiwoWorkload, predicates ...cliutils.PodSelectionPredicate) (string, string, error, bool)
ChoosePodAndContainer allows the User to choose the pod and the container they want to interact with predicates define an optional list of predicates that must be matched in order to include the pod in the list
func RunSelectPodAndContainer ¶
func RunSelectPodAndContainer(ctx context.Context, clients k8s.KubernetesClients, state *tuicomponents.RunState) (tuicomponents.StepResult, tuicomponents.RunStep[tuicomponents.RunState], error)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.